OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Storage invalid" : "Nepareiza glabātuve",
    "Unknown error" : "Nezināma kļūda",
    "All files" : "Visas datnes",
    "Recent" : "Nesenās",
    "Favorites" : "Iecienītie",
    "File could not be found" : "Datni nevar atrast",
    "Move or copy" : "Pārvietot vai kopēt",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "Home" : "Mājas",
    "Close" : "Aizvērt",
    "Could not create folder \"{dir}\"" : "Nevarēja izveidot mapi \"{dir}\"",
    "This will stop your current uploads." : "Tādējādi tiks pārtraukta jūsu pašreizējā augšupielāde.",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Processing files …" : "Notiek failu apstrāde …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturoša datne.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Mape \"{dir}\" vairs neeksistē",
    "Not enough free space" : "Nav pietiekami daudz brīvas vietas",
    "An unknown error has occurred" : "Radusies nezināma kļūda",
    "Uploading …" : "Augšupielādē…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} no {totalSize} ({bitrate})",
    "Actions" : "Darbības",
    "Rename" : "Pārsaukt",
    "Copy" : "Kopēt",
    "Open" : "Atvērt",
    "Disconnect storage" : "Atvienot glabātuvi",
    "Unshare" : "Pārtraukt koplietošanu",
    "Could not load info for file \"{file}\"" : "Nevar ielādēt informāciju par datni \"{file}\"",
    "Files" : "Datnes",
    "Details" : "Detaļas",
    "Select" : "Norādīt",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "This operation is forbidden" : "Šī darbība ir aizliegta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
    "Could not move \"{file}\", target exists" : "Nevarēja pārvietot \"{file}\", mērķis eksistē",
    "Could not move \"{file}\"" : "Nevarēja pārvietot \"{file}\"",
    "copy" : "kopēt",
    "{newName} already exists" : "{newName} jau eksistē",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nevarēja pārsaukt \"{fileName}\", tā vairs neeksistē",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nosaukums \"{targetName}\" jau tiek izmantots mapē \"{dir}\". Lūdzu izvēlies citu nosaukumu.",
    "Could not rename \"{fileName}\"" : "Nevarēja pārsaukt \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nevarēja izveidot datni \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nevarēja izveidot datni \"{file}\", jo tā jau eksistē",
    "Could not create folder \"{dir}\" because it already exists" : "Nevarēja izveidot mapi \"{dir}\", jo tā jau eksistē",
    "Error deleting file \"{fileName}\"." : "Kļūda dzēšot datni \"{fileName}\".",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n datnes","%n datne","%n datnes"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "_including %n hidden_::_including %n hidden_" : ["ieskaitot %n paslēptos","ieskaitot %n paslēptos","ieskaitot %n paslēptos"],
    "You don’t have permission to upload or create files here" : "Jums nav tiesību šeit augšupielādēt vai veidot datnes",
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielādē %n datnes"],
    "New" : "Jauna",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsu glabātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu glabātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
    "View in folder" : "Skatīt mapē",
    "Copied!" : "Nokopēts!",
    "Path" : "Ceļš",
    "_%n byte_::_%n bytes_" : ["%n baiti","%n baits","%n baiti"],
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "New folder" : "Jauna mape",
    "Upload file" : "Augšupielādēt datni",
    "Remove from favorites" : "Noņemt no favorītiem",
    "Add to favorites" : "Pievienot izlasei",
    "An error occurred while trying to update the tags" : "Notika kļūda atjaunojot atzīmi",
    "Added to favorites" : "Pievienot favorītiem",
    "Removed from favorites" : "Noņemt no favorītiem",
    "You added {file} to your favorites" : "Pievienoji {file} saviem favorītiem",
    "You removed {file} from your favorites" : "Noņēmi {file} no saviem favorītiem",
    "File changes" : "Datnes izmaiņas",
    "Created by {user}" : "Izveidoja {user}",
    "Changed by {user}" : "Izmainīja {user}",
    "Deleted by {user}" : "Dzēsa {user}",
    "Restored by {user}" : "Atjaunoja {user}",
    "Renamed by {user}" : "Pārdēvēja {user}",
    "Moved by {user}" : "Pārvietoja {user}",
    "You created {file}" : "Izveidoji {file}",
    "{user} created {file}" : "{user} izveidoja {file}",
    "{file} was created in a public folder" : "{file} tika izveidots publiskajā mapē",
    "You changed {file}" : "Jūs izmainījāt {file}",
    "{user} changed {file}" : "{user} mainīts {file}",
    "You deleted {file}" : "Jūs izdzēsāt {file}",
    "{user} deleted {file}" : "{user} izdzēsa {file}",
    "You restored {file}" : "Tu atjaunoji {file}",
    "{user} restored {file}" : "{user} atjaunoja {file}",
    "You renamed {oldfile} to {newfile}" : "Pārdēvēji {oldfile} uz {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} pārdēvēja {oldfile} uz {newfile}",
    "You moved {oldfile} to {newfile}" : "Pārvietoji {oldfile} uz {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} pārvietoja {oldfile} uz {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datne ir pievienota vai noņemta no jūsu <strong>favorītiem</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Datne vai mape tika <strong>mainīta</strong> vai <strong>pārsaukta</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidota</strong> jauna datne vai mape",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitēt ziņojumus par jūsu <strong>iecienīto datņu</strong> izveidošanu un izmaiņām <em>(tikai datu straumei)</em>",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "%s used" : "%s izmantoti",
    "Settings" : "Iestatījumi",
    "Show hidden files" : "Rādīt slēptās datnes",
    "WebDAV" : "WebDAV",
    "No files in here" : "Šeit nav datņu",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "Files and folders you mark as favorite will show up here" : "Datnes un mapes, ko atzīmēsiet kā favorītus, tiks rādīti šeit",
    "Tags" : "Atzīmes",
    "Deleted files" : "Dzēstās datnes",
    "Shared with others" : "Koplietots ar citiem",
    "Shared with you" : "Koplietots ar tevi",
    "Shared by link" : "Koplietots ar saiti",
    "Text file" : "Teksta datne",
    "New text file.txt" : "Jauna teksta datne.txt",
    "Target folder" : "Mērķa mape",
    "File handling" : "Datņu pārvaldība",
    "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
    "max. possible: " : "maksimālais iespējamais:",
    "Save" : "Saglabāt",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ar PHP-FPM var aizņemt 5 minūtes, kamēr izmaiņas stāsies spēkā.",
    "Missing permissions to edit from here." : "Nepietiekamas tiesības lai rediģētu no šejienes.",
    "Cancel upload" : "Atcelt augšupielādi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
